@@ -8,7 +8,6 @@ import tempfile
 import time
 from typing import Any, Dict, List, Mapping, Tuple
 
-import six
 from boto3 import Session
 
 from localstack.constants import (
@@ -381,6 +380,9 @@ EAGER_SERVICE_LOADING = is_env_true("EAGER_SERVICE_LOADING")
 # Whether to skip downloading additional infrastructure components (e.g., custom Elasticsearch versions)
 SKIP_INFRA_DOWNLOADS = os.environ.get("SKIP_INFRA_DOWNLOADS", "").strip()
 
+# Whether to skip downloading our signed SSL cert.
+SKIP_SSL_CERT_DOWNLOAD = is_env_true("SKIP_SSL_CERT_DOWNLOAD")
+
 # whether to enable legacy record&replay persistence mechanism (default true, but will be disabled in a future release!)
 LEGACY_PERSISTENCE = is_env_not_false("LEGACY_PERSISTENCE")
 
@@ -580,6 +582,9 @@ LAMBDA_CODE_EXTRACT_TIME = int(os.environ.get("LAMBDA_CODE_EXTRACT_TIME") or 25)
 # whether lambdas should use stay open mode if executed in "docker-reuse" executor
 LAMBDA_STAY_OPEN_MODE = is_in_docker and is_env_not_false("LAMBDA_STAY_OPEN_MODE")
 
+# truncate output string slices value
+LAMBDA_TRUNCATE_STDOUT = int(os.getenv("LAMBDA_TRUNCATE_STDOUT") or 2000)
+
 # A comma-delimited string of stream names and its corresponding shard count to
 # initialize during startup.
 # For example: "my-first-stream:1,my-other-stream:2,my-last-stream:1"
@@ -654,6 +659,7 @@ CONFIG_ENV_VARS = [
     "LAMBDA_REMOTE_DOCKER",
     "LAMBDA_REMOVE_CONTAINERS",
     "LAMBDA_STAY_OPEN_MODE",
+    "LAMBDA_TRUNCATE_STDOUT",
     "LEGACY_DOCKER_CLIENT",
     "LOCALSTACK_API_KEY",
     "LOCALSTACK_HOSTNAME",
@@ -667,6 +673,7 @@ CONFIG_ENV_VARS = [
     "S3_SKIP_SIGNATURE_VALIDATION",
     "SERVICES",
     "SKIP_INFRA_DOWNLOADS",
+    "SKIP_SSL_CERT_DOWNLOAD",
     "SQS_PORT_EXTERNAL",
     "STEPFUNCTIONS_LAMBDA_ENDPOINT",
     "SYNCHRONOUS_API_GATEWAY_EVENTS",
@@ -752,7 +759,7 @@ SERVICE_PORTS = parse_service_ports()
 def populate_config_env_var_names():
     global CONFIG_ENV_VARS
 
-    for key, value in six.iteritems(DEFAULT_SERVICE_PORTS):
+    for key, value in DEFAULT_SERVICE_PORTS.items():
         clean_key = key.upper().replace("-", "_")
         CONFIG_ENV_VARS += [
             clean_key + "_BACKEND",
@@ -813,6 +820,15 @@ def get_edge_url(localstack_hostname=None, protocol=None):
     return "%s://%s:%s" % (protocol, localstack_hostname, port)
 
 
+def edge_ports_info():
+    if EDGE_PORT_HTTP:
+        result = "ports %s/%s" % (EDGE_PORT, EDGE_PORT_HTTP)
+    else:
+        result = "port %s" % EDGE_PORT
+    result = "%s %s" % (get_protocol(), result)
+    return result
+
+
 # set log levels
 if DEBUG:
     logging.getLogger("").setLevel(logging.DEBUG)
@@ -829,11 +845,19 @@ if LS_LOG in TRACE_LOG_LEVELS:
 class ServiceProviderConfig(Mapping[str, str]):
     _provider_config: Dict[str, str]
     default_value: str
+    override_prefix: str = "PROVIDER_OVERRIDE_"
 
     def __init__(self, default_value: str):
         self._provider_config = {}
         self.default_value = default_value
 
+    def load_from_environment(self, env: Mapping[str, str] = None):
+        if env is None:
+            env = os.environ
+        for key, value in env.items():
+            if key.startswith(self.override_prefix):
+                self.set_provider(key[len(self.override_prefix) :].lower().replace("_", "-"), value)
+
     def get_provider(self, service: str) -> str:
         return self._provider_config.get(service, self.default_value)
 
@@ -863,11 +887,7 @@ class ServiceProviderConfig(Mapping[str, str]):
 
 SERVICE_PROVIDER_CONFIG = ServiceProviderConfig("default")
 
-for key, value in os.environ.items():
-    if key.startswith("PROVIDER_OVERRIDE_"):
-        SERVICE_PROVIDER_CONFIG.set_provider(
-            key.lstrip("PROVIDER_OVERRIDE_").lower().replace("_", "-"), value
-        )
+SERVICE_PROVIDER_CONFIG.load_from_environment()
 
 # initialize directories
 if is_in_docker:
