@@ -23,6 +23,7 @@ class DockerContainerStatus(Enum):
     DOWN = -1
     NON_EXISTENT = 0
     UP = 1
+    PAUSED = 2
 
 
 class ContainerException(Exception):
@@ -60,6 +61,20 @@ class NoSuchNetwork(ContainerException):
         self.network_name = network_name
 
 
+class RegistryConnectionError(ContainerException):
+    def __init__(self, details: str, message=None, stdout=None, stderr=None) -> None:
+        message = message or f"Connection error: {details}"
+        super().__init__(message, stdout, stderr)
+        self.details = details
+
+
+class AccessDenied(ContainerException):
+    def __init__(self, object_name: str, message=None, stdout=None, stderr=None) -> None:
+        message = message or f"Access denied to {object_name}"
+        super().__init__(message, stdout, stderr)
+        self.object_name = object_name
+
+
 class PortMappings(object):
     """Maps source to target port ranges for Docker port mappings."""
 
@@ -273,7 +288,8 @@ class ContainerConfiguration:
 
     stdin: Optional[str] = None
     user: Optional[str] = None
-    cap_add: Optional[str] = None
+    cap_add: Optional[List[str]] = None
+    cap_drop: Optional[List[str]] = None
     network: Optional[str] = None
     dns: Optional[str] = None
     workdir: Optional[str] = None
@@ -333,6 +349,14 @@ class ContainerClient(metaclass=ABCMeta):
         """
         pass
 
+    @abstractmethod
+    def pause_container(self, container_name: str):
+        """Pauses a container with the given name."""
+
+    @abstractmethod
+    def unpause_container(self, container_name: str):
+        """Unpauses a container with the given name."""
+
     @abstractmethod
     def remove_container(self, container_name: str, force=True, check_existence=False) -> None:
         """Removes container with given name"""
@@ -381,7 +405,31 @@ class ContainerClient(metaclass=ABCMeta):
 
     @abstractmethod
     def pull_image(self, docker_image: str) -> None:
-        """Pulls a image with a given name from a docker registry"""
+        """Pulls a image with a given name from a Docker registry"""
+        pass
+
+    @abstractmethod
+    def push_image(self, docker_image: str) -> None:
+        """Pushes a image with a given name to a Docker registry"""
+        pass
+
+    @abstractmethod
+    def build_image(self, dockerfile_path: str, image_name: str, context_path: str = None) -> None:
+        """Builds an image from the given Dockerfile
+
+        :param dockerfile_path: Path to Dockerfile, or a directory that contains a Dockerfile
+        :param image_name: Name of the image to be built
+        :param context_path: Path for build context (defaults to dirname of Dockerfile)
+        """
+        pass
+
+    @abstractmethod
+    def tag_image(self, source_ref: str, target_name: str) -> None:
+        """Tags an image with a new name
+
+        :param source_ref: Name or ID of the image to be tagged
+        :param target_name: New name (tag) of the tagged image
+        """
         pass
 
     @abstractmethod
@@ -519,7 +567,8 @@ class ContainerClient(metaclass=ABCMeta):
         ports: Optional[PortMappings] = None,
         env_vars: Optional[Dict[str, str]] = None,
         user: Optional[str] = None,
-        cap_add: Optional[str] = None,
+        cap_add: Optional[List[str]] = None,
+        cap_drop: Optional[List[str]] = None,
         network: Optional[str] = None,
         dns: Optional[str] = None,
         additional_flags: Optional[str] = None,
@@ -548,7 +597,8 @@ class ContainerClient(metaclass=ABCMeta):
         ports: Optional[PortMappings] = None,
         env_vars: Optional[Dict[str, str]] = None,
         user: Optional[str] = None,
-        cap_add: Optional[str] = None,
+        cap_add: Optional[List[str]] = None,
+        cap_drop: Optional[List[str]] = None,
         network: Optional[str] = None,
         dns: Optional[str] = None,
         additional_flags: Optional[str] = None,
@@ -570,6 +620,7 @@ class ContainerClient(metaclass=ABCMeta):
         env_vars: Optional[Dict[str, Optional[str]]] = None,
         stdin: Optional[bytes] = None,
         user: Optional[str] = None,
+        workdir: Optional[str] = None,
     ) -> Tuple[bytes, bytes]:
         """Execute a given command in a container
 
@@ -789,3 +840,11 @@ class Util:
                 mount_volumes,
             )
         )
+
+    @staticmethod
+    def resolve_dockerfile_path(dockerfile_path: str) -> str:
+        """If the given path is a directory that contains a Dockerfile, then return the file path to it."""
+        rel_path = os.path.join(dockerfile_path, "Dockerfile")
+        if os.path.isdir(dockerfile_path) and os.path.exists(rel_path):
+            return rel_path
+        return dockerfile_path
